@@ -1,9 +1,10 @@
 __all__ = ['is_isbn10', 'is_isbn13', 'clean', 'mask', 'info', 'meta',
            'to_isbn10', 'to_isbn13', 'get_isbnlike', 'notisbn',
            'canonical', 'get_canonical_isbn', 'editions', 'isbn_from_words',
-           'quiet_errors', 'config', 'setconf']
+           'quiet_errors', 'config', 'setconf', '__version__',
+           'check_version']
 
-__version__ = '2.3.1'
+__version__ = '2.3.2'
 
 from .exceptions import quiet_errors
 from .core import (is_isbn10, is_isbn13, to_isbn10, to_isbn13, clean,
@@ -11,3 +12,4 @@ from .core import (is_isbn10, is_isbn13, to_isbn10, to_isbn13, clean,
 from .ext import (mask, meta, info, editions, isbn_from_words)
 from . import config
 from . import setconf
+from .version import check_version
