@@ -6,6 +6,7 @@ from .metadata import query
 from .infogroup import infogroup
 from .dev.wcated import query as qed
 from .mask import mask as msk
+from .words import goos
 
 
 def mask(isbn, separator='-'):
@@ -26,3 +27,10 @@ def info(isbn):
 def editions(isbn):
     """ Returns the list of ISBNs of editions related with this ISBN """
     return qed(isbn)
+
+
+def isbn_from_words(words):
+    """ Returns the most probable ISBN from a list of words from title
+        and author's name (uses Google Search)
+    """
+    return goos(words)
